@@ -8,7 +8,7 @@ use WWW::LogicBoxes::DomainTransfer;
 
 use Carp;
 
-our $VERSION = '1.7.0'; # VERSION
+our $VERSION = '1.8.0'; # VERSION
 # ABSTRACT: Domain Factory for Building Domain Objects from Responses
 
 sub construct_from_response {
@@ -23,7 +23,7 @@ sub construct_from_response {
         if( $response->{actiontype} eq 'AddTransferDomain' ) {
             return WWW::LogicBoxes::DomainTransfer->construct_from_response( $response );
         }
-        elsif( $response->{actiontype} eq 'DelDomain' ) {
+        elsif( $response->{actiontype} eq 'DelDomain' || $response->{actiontype} eq 'ModContact' ) {
             return WWW::LogicBoxes::Domain->construct_from_response( $response );
         }
         else {
